aboutsummaryrefslogtreecommitdiff
path: root/Common/src/com/googlecode/android_scripting/facade/bluetooth/GattClientFacade.java
diff options
context:
space:
mode:
Diffstat (limited to 'Common/src/com/googlecode/android_scripting/facade/bluetooth/GattClientFacade.java')
-rw-r--r--Common/src/com/googlecode/android_scripting/facade/bluetooth/GattClientFacade.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/Common/src/com/googlecode/android_scripting/facade/bluetooth/GattClientFacade.java b/Common/src/com/googlecode/android_scripting/facade/bluetooth/GattClientFacade.java
index f6edde8a..e2286724 100644
--- a/Common/src/com/googlecode/android_scripting/facade/bluetooth/GattClientFacade.java
+++ b/Common/src/com/googlecode/android_scripting/facade/bluetooth/GattClientFacade.java
@@ -1740,7 +1740,7 @@ public class GattClientFacade extends RpcReceiver {
* @param index the bluetooth gatt index
* @param minConnectionInterval minimum connection interval
* @param maxConnectionInterval maximum connection interval
* @param slaveLatency maximum slave latency
* @param supervisionTimeout supervision timeout
* @return boolean True if successful False otherwise.
* @throws Exception
@@ -1750,7 +1750,7 @@ public class GattClientFacade extends RpcReceiver {
@RpcParameter(name = "index") Integer index,
@RpcParameter(name = "minConnectionInterval") Integer minConnectionInterval,
@RpcParameter(name = "maxConnectionInterval") Integer maxConnectionInterval,
- @RpcParameter(name = "slaveLatency") Integer slaveLatency,
+ @RpcParameter(name = "peripheralLatency") Integer peripheralLatency,
@RpcParameter(name = "supervisionTimeout") Integer supervisionTimeout,
@RpcParameter(name = "minConnectionEventLen") Integer minConnectionEventLen,
@RpcParameter(name = "maxConnectionEventLen") Integer maxConnectionEventLen)
@@ -1758,7 +1758,7 @@ public class GattClientFacade extends RpcReceiver {
boolean result = false;
if (mBluetoothGattList.get(index) != null) {
result = mBluetoothGattList.get(index).requestLeConnectionUpdate(
- minConnectionInterval, maxConnectionInterval, slaveLatency, supervisionTimeout,
+ minConnectionInterval, maxConnectionInterval, peripheralLatency, supervisionTimeout,
minConnectionEventLen, maxConnectionEventLen);
} else {
throw new Exception("Invalid index input:" + index);
@@ -1740,7 +1740,7 @@ public class GattClientFacade extends RpcReceiver {
* @param minConnectionInterval minimum connection interval
* @param maxConnectionInterval maximum connection interval
- * @param slaveLatency maximum slave latency
+ * @param peripheralLatency maximum peripheral latency
* @param supervisionTimeout supervision timeout
* @return boolean True if successful False otherwise.